Struct boomphf_patched::hashmap::NoKeyBoomHashMap
source · Expand description
A HashMap data structure where the mapping between keys and values is encoded in a Mphf. Keys are not stored - this can greatly improve the memory consumption, but can only be used if you can guarantee that you will only query for keys that were in the original set. Querying for a new key will return a random value, silently.
Fields
mphf: Mphf<K>values: Vec<D1>Implementations
sourceimpl<K, D1> NoKeyBoomHashMap<K, D1>where
K: Hash + Debug + PartialEq + Send + Sync,
D1: Debug,
impl<K, D1> NoKeyBoomHashMap<K, D1>where
K: Hash + Debug + PartialEq + Send + Sync,
D1: Debug,
pub fn new_parallel(keys: Vec<K>, values: Vec<D1>) -> NoKeyBoomHashMap<K, D1>
pub fn new_with_mphf(mphf: Mphf<K>, values: Vec<D1>) -> NoKeyBoomHashMap<K, D1>